@@ -27,14 +27,19 @@ public:
     ~NextPushProvider();
 
     bool loadSettings(const QSettings &settings) override;
-    void connectToProvider() override;
+    void resetSettings(QSettings &settings) override;
+    void connectToProvider(Urgency urgency) override;
     void disconnectFromProvider() override;
     void registerClient(const Client &client) override;
     void unregisterClient(const Client &client) override;
+    void acknowledgeMessage(const Client &client, const QString &messageIdentifier) override;
+
+    static constexpr inline auto Id = QLatin1StringView("NextPush");
+protected:
+    void doChangeUrgency(Urgency urgency) override;
 
-    static constexpr const char Id[] = "NextPush";
 private:
-    void waitForMessage();
+    void waitForMessage(Urgency urgency);
     QNetworkRequest prepareRequest(const char *restCmd, const QString &restArg = {}) const;
 
     QUrl m_url;
